//////////////////////////////////////////////////////////////////////////////////
// Module	 : Win2600.h														//
// Function  : Declarations for library functions			                    //
// Target OS : Windows, Linux													//
// Usage	 : Included by all apps using 2600 family I/O systems				//
// Copyright : (C) 2004 Sensoray												//
//////////////////////////////////////////////////////////////////////////////////


// Try to determine Windows target.
#if defined(WIN32) || defined(__WIN32__)
#define OS_WINDOWS
#endif

#include "App2600.h"


#ifndef DEF_APP2600 //============================================================


#ifdef OS_WINDOWS

// Error codes returned by S2600_DLLOpen() ------------------
#define ERR_LOAD_DLL	0x10		// Failed to open S2600.DLL.
#define ERR_FUNCADDR	0x20		// Failed to find function name in S2600.DLL.

#endif //OS_WINDOWS


// S2600.DLL Startup and Shutdown functions -----------------

#ifdef OS_WINDOWS

#ifdef __cplusplus
extern "C" {
#endif

extern 	GWERR S26_DLLOpen( char *workdir, int NumMMs );		// Open DLL and initialize function pointers.
extern void		S26_DLLClose( void );				// Close DLL.

#ifdef __cplusplus
}
#endif

#endif //OS_WINDOWS


#define DEF_APP2600
#endif // #ifndef DEF_APP2600 ======================================================


#ifndef XFUNC26

#ifdef OS_WINDOWS

// If compiling an app module, declare as externals the pointers to DLL functions in WIN2600.C.
#define XFUNC26(RTNTYPE,FUNCNAME,ARGS)		extern RTNTYPE (__stdcall *FUNCNAME) ARGS

#else

// Declare as function prototypes.
#define XFUNC26(RTNTYPE,FUNCNAME,ARGS)		extern RTNTYPE FUNCNAME ARGS

#endif //OS_xxx

#endif //XFUNC26


///////////////////////////////////////////////////////////////////////////////////
// Functions that are exported.
///////////////////////////////////////////////////////////////////////////////////

#ifdef __cplusplus
extern "C" {
#endif

// Initialization, shutdown and status.
XFUNC26( u32, S26_DriverOpen,						( u32 NumMMs ) );
XFUNC26( void,  S26_DriverClose,					( void ) );
XFUNC26( u32, S26_BoardOpen,						( HBD hbd, char *CLDotAdrs, char *MMDotAdrs ) );
XFUNC26( void,  S26_BoardClose,						( HBD hbd ) );
XFUNC26( char* ,S26_GetRelease,						( void ) );
XFUNC26( GWERR, S26_RegisterAllIoms,				( HBD hbd, u32 msec, u16 *NumBoards, u16 *IomTypeList, u8 *IomStatus, u32 retries ) );
XFUNC26( GWERR, S26_ResetIom,						( HBD hbd, IOMPORT IomPort, u32 msec, u32 retries ) );
XFUNC26( BOOL,  S26_ResetNetwork,					( HBD hbd ) );

// Asynchronous communications.
XFUNC26( GWERR,  S26_ComClearFlags,					( HBD hbd, u8 LogDev, u32 msec, u32 retries ) );
XFUNC26( GWERR,  S26_ComClose,						( HBD hbd, u8 LogDev, u32 msec, u32 retries ) );
XFUNC26( GWERR,  S26_ComEndBreak,					( HBD hbd, u8 LogDev, u32 msec, u32 retries ) );
XFUNC26( GWERR,  S26_ComFlush,						( HBD hbd, u8 LogDev, u32 msec, u32 retries ) );
XFUNC26( GWERR,  S26_ComGetRxCount,					( HBD hbd, u8 LogDev, u16 *CharCount, u32 msec, u32 retries ) );
XFUNC26( GWERR,  S26_ComGetTxCount,					( HBD hbd, u8 LogDev, u16 *CharCount, u32 msec, u32 retries ) );
XFUNC26( GWERR,  S26_ComOpen,						( HBD hbd, u8 LogDev, u32 msec, u32 retries ) );
XFUNC26( GWERR,  S26_ComReceive,					( HBD hbd, u8 LogDev, char *MsgBuf, u16 *MsgLen, u32 msec, u32 retries ) );
XFUNC26( GWERR,  S26_ComSend,						( HBD hbd, u8 LogDev, char *MsgBuf, u16 MsgLen, u32 msec, u32 retries ) );
XFUNC26( GWERR,  S26_ComSetMode,					( HBD hbd, u8 LogDev, u16 ClockDiv, u8 Attributes, u8 LEDs, u32 msec, u32 retries ) );
XFUNC26( GWERR,  S26_ComSetBreakChar,				( HBD hbd, u8 LogDev, u8 BreakChar, u32 msec, u32 retries ) );
XFUNC26( GWERR,  S26_ComStartBreak,					( HBD hbd, u8 LogDev, u32 msec, u32 retries ) );

// Gateway transaction scheduling --------------------------------

// Transaction control.
XFUNC26( XACT,  S26_SchedOpen,						( HBD hbd, u32 retries ) );
XFUNC26( GWERR, S26_SchedExecute,					( XACT x, u32 msec, u8 *IomStatus ) );
XFUNC26( GWERR, S26_SchedExecuteStart,				( XACT x ) );
XFUNC26( u32, S26_SchedExecuteIsResponded,		    ( XACT x ) );
XFUNC26( GWERR, S26_SchedExecuteWait,				( XACT x, u32 msec ) );
XFUNC26( GWERR, S26_SchedExecuteFinish,				( XACT x, u8 *IomStatus ) );

// General-purpose IOM transactions.
XFUNC26( GWERR, S26_Sched2600_Nop,					( XACT x, IOMPORT IomPort ) );
XFUNC26( GWERR, S26_Sched2600_ClearStatus,			( XACT x, IOMPORT IomPort, u8 BitMask ) );
XFUNC26( GWERR, S26_Sched2600_IomGetProductID,		( XACT x, IOMPORT IomPort, u16 *ProductID ) );
XFUNC26( GWERR, S26_Sched2600_GetFirmwareVersion,	( XACT x, IOMPORT IomPort, u16 *Version ) );
XFUNC26( GWERR, S26_Sched2600_GetAddress,			( XACT x, IOMPORT IomPort, u8 *adrs ) );

// MM.
XFUNC26( GWERR, S26_Sched2601_GetLinkStatus,		( XACT x, u16 *LinkFlags ) );
XFUNC26( GWERR, S26_Sched2601_GetInterlocks,		( XACT x, u8 *LockFlags ) );
XFUNC26( GWERR, S26_Sched2601_SetWatchdog,			( XACT x, u8 NumTenthSeconds ) );

// 2608 analog I/O.
XFUNC26( double,S26_2608_AdcCorrect,				( HBD hbd, IOMPORT IomPort, s16 RawData, BOOL IsHighGain ) );
XFUNC26( GWERR, S26_2608_WriteEeprom,				( HBD hbd, IOMPORT IomPort, u32 msec, u8 address, u8 value, u32 retries ) );
XFUNC26( GWERR, S26_Sched2608_GetAins,				( XACT x, IOMPORT IomPort, double *volts, BOOL Integrated ) );
XFUNC26( GWERR, S26_Sched2608_GetAinTypes,			( XACT x, IOMPORT IomPort, u8 *types ) );
XFUNC26( GWERR, S26_Sched2608_GetAout,				( XACT x, IOMPORT IomPort, u8 chan, double *volts ) );
XFUNC26( GWERR, S26_Sched2608_GetCalData,			( XACT x, IOMPORT IomPort, s16 *caldata ) );
XFUNC26( GWERR, S26_Sched2608_ReadEeprom,			( XACT x, IOMPORT IomPort, u8 address, u8 *value ) );
XFUNC26( GWERR, S26_Sched2608_SetAinTypes,			( XACT x, IOMPORT IomPort, const u8 *types ) );
XFUNC26( GWERR, S26_Sched2608_SetAout,				( XACT x, IOMPORT IomPort, u8 chan, double volts ) );
XFUNC26( GWERR, S26_Sched2608_SetTempUnits,			( XACT x, IOMPORT IomPort, int DegreesF ) );
XFUNC26( GWERR, S26_Sched2608_SetLineFreq,			( XACT x, IOMPORT IomPort, u8 freq ) );

// 2610 digital I/O.
XFUNC26( GWERR, S26_Sched2610_GetInputs,			( XACT x, IOMPORT IomPort, u8 *states ) );
XFUNC26( GWERR, S26_Sched2610_GetModes,				( XACT x, IOMPORT IomPort, u8 *modes ) );
XFUNC26( GWERR, S26_Sched2610_GetOutputs,			( XACT x, IOMPORT IomPort, u8 *states ) );
XFUNC26( GWERR, S26_Sched2610_GetPwmRatio,			( XACT x, IOMPORT IomPort, u8 chan, u8 *OnTime, u8 *OffTime ) );
XFUNC26( GWERR, S26_Sched2610_SetModes,				( XACT x, IOMPORT IomPort, u8 *modes ) );
XFUNC26( GWERR, S26_Sched2610_SetOutputs,			( XACT x, IOMPORT IomPort, u8 *states ) );
XFUNC26( GWERR, S26_Sched2610_SetPwmRatio,			( XACT x, IOMPORT IomPort, u8 chan, u8 OnTime, u8 OffTime ) );

// 2612 high-resolution ADC.
XFUNC26( GWERR, S26_Sched2612_SetMode,		  	    ( XACT x, IOMPORT IomPort, u8 chan, u32 mode ) );
XFUNC26( GWERR, S26_Sched2612_SetVoltages,			( XACT x, IOMPORT IomPort, u8 volts ) );
XFUNC26( GWERR, S26_Sched2612_GetValues,			( XACT x, IOMPORT IomPort, s32 *values, u8 *tstamp ) );
XFUNC26( GWERR, S26_Sched2612_RefreshData,          ( XACT x, IOMPORT IomPort ) );

XFUNC26( GWERR, S26_2612_RegisterZero,              ( HBD hbd, IOMPORT IomPort, u32 msec, u8 chan, u32 nsmp ) );
XFUNC26( GWERR, S26_2612_RegisterSpan,              ( HBD hbd, IOMPORT IomPort, u32 msec, u8 chan, u32 nsmp, double load ) );
XFUNC26( GWERR, S26_2612_RegisterTare,              ( HBD hbd, IOMPORT IomPort, u32 msec, u8 chan, u32 nsmp ) );
XFUNC26( double, S26_2612_GetCalibratedValue,       ( HBD hbd, IOMPORT IomPort, u8 chan, u32 *sample ) );
XFUNC26( double, S26_2612_GetOffset,                ( HBD hbd, IOMPORT IomPort, u8 chan ) );
XFUNC26( double, S26_2612_GetScale,                 ( HBD hbd, IOMPORT IomPort, u8 chan ) );
XFUNC26( double, S26_2612_GetTare,                  ( HBD hbd, IOMPORT IomPort, u8 chan ) );
XFUNC26( GWERR, S26_2612_SetCalibrations,           ( HBD hbd, IOMPORT IomPort, u8 chan, double Offset, double Scale, double Tare ) );

XFUNC26( GWERR, S26_2612_SaveCalibrations,          ( HBD hbd, IOMPORT IomPort, u32 msec, u8 chan ) );
XFUNC26( GWERR, S26_2612_RestoreCalibrations,       ( HBD hbd, IOMPORT IomPort, u32 msec, u8 chan ) );

// 2620 counter.
XFUNC26( GWERR, S26_Sched2620_GetCommonControl,		( XACT x, IOMPORT IomPort, u16 *period, u8 *tstamp ) );
XFUNC26( GWERR, S26_Sched2620_GetCounts,			( XACT x, IOMPORT IomPort, u8 chan, u32 *value, u16 *tstamp ) );
XFUNC26( GWERR, S26_Sched2620_GetMode,				( XACT x, IOMPORT IomPort, u8 chan, u16 *mode ) );
XFUNC26( GWERR, S26_Sched2620_GetPreload,			( XACT x, IOMPORT IomPort, u8 chan, u8 reg, u32 *value ) );
XFUNC26( GWERR, S26_Sched2620_GetStatus,			( XACT x, IOMPORT IomPort, u8 chan, u16 *status ) );
XFUNC26( GWERR, S26_Sched2620_SetCommonControl,		( XACT x, IOMPORT IomPort, u16 gperiod, u8 tstamp ) );
XFUNC26( GWERR, S26_Sched2620_SetControlReg,		( XACT x, IOMPORT IomPort, u8 chan, u8 DataVal ) );
XFUNC26( GWERR, S26_Sched2620_SetMode,				( XACT x, IOMPORT IomPort, u8 chan, u16 mode ) );
XFUNC26( GWERR, S26_Sched2620_SetModeEncoder,		( XACT x, IOMPORT IomPort, u8 chan, u16 ActLowX, u16 HardPreload, u16 ClkMode ) );
XFUNC26( GWERR, S26_Sched2620_SetModeFreqMeas,		( XACT x, IOMPORT IomPort, u8 chan, u16 InternalGate ) );
XFUNC26( GWERR, S26_Sched2620_SetModePeriodMeas,	( XACT x, IOMPORT IomPort, u8 chan, u16 ActLowX ) );
XFUNC26( GWERR, S26_Sched2620_SetModePulseGen,		( XACT x, IOMPORT IomPort, u8 chan, u16 ActLowX, u16 HardTrig, u16 ActLowOut ) );
XFUNC26( GWERR, S26_Sched2620_SetModePulseMeas,		( XACT x, IOMPORT IomPort, u8 chan, u16 ActLowX ) );
XFUNC26( GWERR, S26_Sched2620_SetModePwmGen,		( XACT x, IOMPORT IomPort, u8 chan, u16 ActLowOut ) );
XFUNC26( GWERR, S26_Sched2620_SetPreload,			( XACT x, IOMPORT IomPort, u8 chan, u8 reg, u32 value ) );

// 2631 motor controller.
XFUNC26( GWERR, S26_Sched2631_SetControlReg,        ( XACT x, IOMPORT IomPort, u8 DataVal ) );
XFUNC26( GWERR, S26_Sched2631_GetStatus,            ( XACT x, IOMPORT IomPort, u16 *status ) );
XFUNC26( GWERR, S26_Sched2631_SetPreload,           ( XACT x, IOMPORT IomPort, u8 reg, u32 value ) );
XFUNC26( GWERR, S26_Sched2631_GetPreload,           ( XACT x, IOMPORT IomPort, u8 reg, u32 *value ) );
XFUNC26( GWERR, S26_Sched2631_GetCounts,            ( XACT x, IOMPORT IomPort, u32 *value, u16 *tstamp ) );
XFUNC26( GWERR, S26_Sched2631_SetCommonControl,     ( XACT x, IOMPORT IomPort, u16 period, u8 tstamp ) );
XFUNC26( GWERR, S26_Sched2631_GetCommonControl,     ( XACT x, IOMPORT IomPort, u16 *period, u8 *tstamp ) );
XFUNC26( GWERR, S26_Sched2631_SetMode,              ( XACT x, IOMPORT IomPort, u16 mode ) );
XFUNC26( GWERR, S26_Sched2631_GetMode,              ( XACT x, IOMPORT IomPort, u16 *mode ) );
XFUNC26( GWERR, S26_Sched2631_SetModeEncoder,       ( XACT x, IOMPORT IomPort, u16 ActLowX, u16 HardPreload, u16 ClkMode ) );
XFUNC26( GWERR, S26_Sched2631_SetModePulseGen,      ( XACT x, IOMPORT IomPort, u16 ActLowX, u16 HardTrig, u16 ActLowOut ) );
XFUNC26( GWERR, S26_Sched2631_SetModePwmGen,        ( XACT x, IOMPORT IomPort, u16 ActLowOut ) );
XFUNC26( GWERR, S26_Sched2631_SetModePulseMeas,     ( XACT x, IOMPORT IomPort, u16 ActLowX ) );
XFUNC26( GWERR, S26_Sched2631_SetModePeriodMeas,    ( XACT x, IOMPORT IomPort, u16 ActLowX ) );
XFUNC26( GWERR, S26_Sched2631_SetModeFreqMeas,      ( XACT x, IOMPORT IomPort, u16 igate ) );

XFUNC26( GWERR, S26_Sched2631_OutEnable,            ( XACT x, IOMPORT IomPort, u8 enable ) );
XFUNC26( GWERR, S26_Sched2631_SetOutMode,           ( XACT x, IOMPORT IomPort, u8 mode ) );
XFUNC26( GWERR, S26_Sched2631_SetOutputFrq,         ( XACT x, IOMPORT IomPort, u32 frequency ) );
XFUNC26( GWERR, S26_Sched2631_SetPWMFrq,            ( XACT x, IOMPORT IomPort, u32 frequency ) );
XFUNC26( GWERR, S26_Sched2631_SetAmpl,              ( XACT x, IOMPORT IomPort, u32 amplitude ) );

// 2650 relay.
XFUNC26( GWERR, S26_Sched2650_GetInputs,			( XACT x, IOMPORT IomPort, u8 *states ) );
XFUNC26( GWERR, S26_Sched2650_GetOutputs,			( XACT x, IOMPORT IomPort, u8 *states ) );
XFUNC26( GWERR, S26_Sched2650_SetOutputs,			( XACT x, IOMPORT IomPort, u8 *states ) );

// 2652 relay.
XFUNC26( GWERR, S26_Sched2652_GetInputs,			( XACT x, IOMPORT IomPort, u8 *states ) );
XFUNC26( GWERR, S26_Sched2652_GetOutputs,			( XACT x, IOMPORT IomPort, u8 *states ) );
XFUNC26( GWERR, S26_Sched2652_SetOutputs,			( XACT x, IOMPORT IomPort, u8 *states ) );
XFUNC26( GWERR, S26_Sched2652_GetModes,				( XACT x, IOMPORT IomPort, u8 *modes ) );
XFUNC26( GWERR, S26_Sched2652_GetPwmRatio,			( XACT x, IOMPORT IomPort, u8 chan, u8 *OnTime, u8 *OffTime ) );
XFUNC26( GWERR, S26_Sched2652_SetModes,				( XACT x, IOMPORT IomPort, u8 *modes ) );
XFUNC26( GWERR, S26_Sched2652_SetPwmRatio,			( XACT x, IOMPORT IomPort, u8 chan, u8 OnTime, u8 OffTime ) );

// 2653 relay.
XFUNC26( GWERR, S26_Sched2653_GetInputs,			( XACT x, IOMPORT IomPort, u8 *states ) );
XFUNC26( GWERR, S26_Sched2653_GetOutputs,			( XACT x, IOMPORT IomPort, u8 *states ) );
XFUNC26( GWERR, S26_Sched2653_SetOutputs,			( XACT x, IOMPORT IomPort, u8 *states ) );
XFUNC26( GWERR, S26_Sched2653_GetModes,				( XACT x, IOMPORT IomPort, u8 *modes ) );
XFUNC26( GWERR, S26_Sched2653_SetModes,				( XACT x, IOMPORT IomPort, u8 *modes ) );
XFUNC26( GWERR, S26_Sched2653_GetPwmRatio,			( XACT x, IOMPORT IomPort, u8 chan, u8 *OnTime, u8 *OffTime ) );
XFUNC26( GWERR, S26_Sched2653_SetPwmRatio,			( XACT x, IOMPORT IomPort, u8 chan, u8 OnTime, u8 OffTime ) );

#ifdef __cplusplus
}
#endif

